==> haskell-lattices-2.2.1-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2.1
visibility:           public
id:                   lattices-2.2.1-C9lI6B5GaCzIb8MRm0WgLX
key:                  lattices-2.2.1-C9lI6B5GaCzIb8MRm0WgLX
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  90cf2cf6b74f36732707458c05ab610e
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2.1-C9lI6B5GaCzIb8MRm0WgLX
depends:
    QuickCheck-2.14.3-8uOdgqaEmIi7siaoGpKSGc base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0
    foldable1-classes-compat-0.1.1-Emsww9pqdXNJ4xffp8s9pk
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM
    integer-logarithms-1.0.4-9ChOKKnn3V94Ohx5uWLH4h
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-B5aimCc1FWxEGJ7QLVWmO8
    universe-reverse-instances-1.1.2-BIp5NCB0ZHwKQclzyygxmB
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lattices-2.2.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lattices
version:              2.2.1
visibility:           public
id:                   lattices-2.2.1-HAkY8YzI3NO4nB7yc1hUgj
key:                  lattices-2.2.1-HAkY8YzI3NO4nB7yc1hUgj
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  cf8275866506e2d41198e61683ba615d
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Unicode
    Algebra.Lattice.Wide Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lattices-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lattices
hs-libraries:         HSlattices-2.2.1-HAkY8YzI3NO4nB7yc1hUgj
depends:
    QuickCheck-2.14.3-1v0srcb4FkGBzkvUbxpBuR base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0
    foldable1-classes-compat-0.1.1-7jxRP6wPbhULZGodlxjKKy
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb
    integer-logarithms-1.0.4-FOoeti4VCmd10BoMf8vsn4
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    universe-base-1.1.4-CV6urbu57h51ZBsT6eXQ0N
    universe-reverse-instances-1.1.2-A4yIWL8gIfdHMsndh92xKi
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
